Slot: mixins - LinkML Model

# Slot: mixins

List of definitions to be mixed in. Targets may be any definition of the same type

URI: linkml:mixins

## Domain and Range

Definition → 0..* Definition

## Parents

## Children

- class_definition➞mixins
- permissible_value➞mixins
- slot_definition➞mixins

## Used by

- Definition

## Other properties

Aliases: |  | traits
Comments: |  | mixins act in the same way as parents (is_a). They allow a model to have a primary strict hierachy, while keeping the benefits of multiple inheritance
See also: |  | https://en.wikipedia.org/wiki/Mixin